@@ -1,6 +1,5 @@
 package Bitcoin::Crypto;
-$Bitcoin::Crypto::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::VERSION = '2.00001';
+$Bitcoin::Crypto::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -159,7 +158,9 @@ L<https://github.com/bitcoin/bips>
 
 =head1 AUTHOR
 
-Bartosz Jarzyna E<lt>bbrtj.pro@gmail.comE<gt> (L<Support me|https://bbrtj.eu/support>)
+Bartosz Jarzyna E<lt>bbrtj.pro@gmail.comE<gt>
+
+Consider supporting: L<https://bbrtj.eu/support>
 
 =head1 COPYRIGHT AND LICENSE
 
