@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::BIP44;
-$Bitcoin::Crypto::BIP44::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::BIP44::VERSION = '2.00001';
+$Bitcoin::Crypto::BIP44::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -12,6 +11,8 @@ use Bitcoin::Crypto::Types qw(BIP44Purpose PositiveOrZeroInt Bool Enum);
 use Bitcoin::Crypto::Network;
 use Bitcoin::Crypto::Exception;
 
+use namespace::clean;
+
 sub _get_network_constant
 {
 	my ($network) = @_;
@@ -111,7 +112,7 @@ sub as_string
 __END__
 =head1 NAME
 
-Bitcoin::Crypto::BIP44 - BIP44 implementation in Perl
+Bitcoin::Crypto::BIP44 - BIP44 implementation
 
 =head1 SYNOPSIS
 
