@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Base58;
-$Bitcoin::Crypto::Base58::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Base58::VERSION = '2.00001';
+$Bitcoin::Crypto::Base58::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -92,7 +91,7 @@ __END__
 
 =head1 NAME
 
-Bitcoin::Crypto::Base58 - Bitcoin base58 helpers
+Bitcoin::Crypto::Base58 - Base58 helpers
 
 =head1 SYNOPSIS
 
