@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Key::ExtPrivate;
-$Bitcoin::Crypto::Key::ExtPrivate::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Key::ExtPrivate::VERSION = '2.00001';
+$Bitcoin::Crypto::Key::ExtPrivate::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -8,11 +7,12 @@ use Moo;
 use Crypt::Mac::HMAC qw(hmac);
 use Bitcoin::BIP39 qw(bip39_mnemonic_to_entropy);
 use Type::Params -sigs;
+use Carp qw(carp);
 
 use Bitcoin::Crypto::BIP44;
 use Bitcoin::Crypto::Key::ExtPublic;
 use Bitcoin::Crypto::Constants;
-use Bitcoin::Crypto::Helpers qw(ensure_length carp_once);
+use Bitcoin::Crypto::Helpers qw(ensure_length);
 use Bitcoin::Crypto::Util qw(mnemonic_to_seed);
 use Bitcoin::Crypto::Types qw(Object Str ByteStr HashRef Maybe);
 use Bitcoin::Crypto::Exception;
@@ -26,7 +26,7 @@ sub _is_private { 1 }
 sub generate_mnemonic
 {
 	shift;
-	carp_once 'Bitcoin::Crypto::Key::ExtPrivate->generate_mnemonic is deprecated.'
+	carp 'Bitcoin::Crypto::Key::ExtPrivate->generate_mnemonic is deprecated.'
 		. ' Use generate_mnemonic function from Bitcoin::Crypto::Util instead.';
 
 	goto \&Bitcoin::Crypto::Util::generate_mnemonic;
@@ -35,7 +35,7 @@ sub generate_mnemonic
 sub mnemonic_from_entropy
 {
 	shift;
-	carp_once 'Bitcoin::Crypto::Key::ExtPrivate->mnemonic_from_entropy is deprecated.'
+	carp 'Bitcoin::Crypto::Key::ExtPrivate->mnemonic_from_entropy is deprecated.'
 		. ' Use mnemonic_from_entropy function from Bitcoin::Crypto::Util instead.';
 
 	goto \&Bitcoin::Crypto::Util::mnemonic_from_entropy;
@@ -178,7 +178,7 @@ sub from_hex_seed
 {
 	my ($class, $seed) = @_;
 
-	carp_once "$class->from_hex_seed(\$seed) is now deprecated. Use $class->from_seed([hex => \$seed]) instead";
+	carp "$class->from_hex_seed(\$seed) is now deprecated. Use $class->from_seed([hex => \$seed]) instead";
 
 	return $class->from_seed([hex => $seed]);
 }
