@@ -1,15 +1,14 @@
 package Bitcoin::Crypto::Role::BasicKey;
-$Bitcoin::Crypto::Role::BasicKey::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Role::BasicKey::VERSION = '2.00001';
+$Bitcoin::Crypto::Role::BasicKey::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
 use Type::Params -sigs;
+use Carp qw(carp);
 
 use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Types qw(Object Str ByteStr FormatStr);
 use Bitcoin::Crypto::Util qw(to_format);
-use Bitcoin::Crypto::Helpers qw(carp_once);
 use Moo::Role;
 
 with qw(
@@ -22,7 +21,7 @@ around BUILDARGS => sub {
 	my ($orig, $class, @params) = @_;
 
 	if (@params == 1) {
-		carp_once "$class->new(\$bytes) is now deprecated. Use $class->from_serialized(\$bytes) instead";
+		carp "$class->new(\$bytes) is now deprecated. Use $class->from_serialized(\$bytes) instead";
 		unshift @params, 'key_instance';
 	}
 
@@ -59,7 +58,7 @@ sub from_hex
 {
 	my ($class, $val) = @_;
 
-	carp_once "$class->from_hex(\$str) is now deprecated. Use $class->from_serialized([hex => \$str]) instead";
+	carp "$class->from_hex(\$str) is now deprecated. Use $class->from_serialized([hex => \$str]) instead";
 	return $class->from_serialized([hex => $val]);
 }
 
@@ -68,7 +67,7 @@ sub to_hex
 	my ($self) = @_;
 
 	my $class = ref $self;
-	carp_once
+	carp
 		"$class->to_hex() is now deprecated. Use Bitcoin::Crypto::Util::to_format [hex => $class->to_serialized()] instead";
 	return to_format [hex => $self->to_serialized];
 }
@@ -77,7 +76,7 @@ sub from_bytes
 {
 	my ($class, $bytes) = @_;
 
-	carp_once "$class->from_bytes() is now deprecated. Use $class->from_serialized() instead";
+	carp "$class->from_bytes() is now deprecated. Use $class->from_serialized() instead";
 	return $class->from_serialized($bytes);
 }
 
@@ -86,7 +85,7 @@ sub to_bytes
 	my ($self) = @_;
 
 	my $class = ref $self;
-	carp_once "$class->to_bytes() is now deprecated. Use $class->to_serialized() instead";
+	carp "$class->to_bytes() is now deprecated. Use $class->to_serialized() instead";
 	return $self->to_serialized;
 }
 
