@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Script;
-$Bitcoin::Crypto::Script::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Script::VERSION = '2.00001';
+$Bitcoin::Crypto::Script::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -10,12 +9,12 @@ use Mooish::AttributeBuilder -standard;
 use Try::Tiny;
 use Scalar::Util qw(blessed);
 use Type::Params -sigs;
+use Carp qw(carp);
 
 use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Base58 qw(encode_base58check decode_base58check);
 use Bitcoin::Crypto::Bech32 qw(encode_segwit decode_segwit get_hrp);
 use Bitcoin::Crypto::Constants;
-use Bitcoin::Crypto::Helpers qw(carp_once);
 use Bitcoin::Crypto::Util qw(hash160 hash256);
 use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Types qw(Maybe ArrayRef HashRef Str Object ByteStr Any ScriptType ScriptDesc);
@@ -155,6 +154,10 @@ sub _build
 				$witness->(@_, 'P2WSH', 0, 32);
 			},
 
+			P2TR => sub {
+				$witness->(@_, 'P2TR', 1, 32);
+			},
+
 			NULLDATA => sub {
 				my ($self, $data) = @_;
 
@@ -468,7 +471,7 @@ sub get_script
 {
 	my ($self) = @_;
 
-	carp_once "Bitcoin::Crypto::Script->get_script is deprecated. Use Bitcoin::Crypto::Script->to_serialized instead.";
+	carp "Bitcoin::Crypto::Script->get_script is deprecated. Use Bitcoin::Crypto::Script->to_serialized instead.";
 	return $self->to_serialized;
 }
 
@@ -485,7 +488,7 @@ sub get_hash
 
 sub get_script_hash
 {
-	carp_once "Bitcoin::Crypto::Script->get_script_hash is deprecated. Use Bitcoin::Crypto::Script->get_hash instead.";
+	carp "Bitcoin::Crypto::Script->get_script_hash is deprecated. Use Bitcoin::Crypto::Script->get_hash instead.";
 	goto \&get_hash;
 }
 
@@ -618,15 +621,24 @@ sub get_address
 	return undef
 		unless $self->has_type && defined $address;
 
-	if ($self->is_native_segwit) {
+	my $segwit = sub {
+		my ($version, $address) = @_;
 
 		# network field is not required, lazy check for completeness
 		Bitcoin::Crypto::Exception::NetworkConfig->raise(
 			'this network does not support segregated witness'
 		) unless $self->network->supports_segwit;
 
-		my $version = pack 'C', Bitcoin::Crypto::Constants::segwit_witness_version;
 		return encode_segwit($self->network->segwit_hrp, $version . $address);
+	};
+
+	if ($self->is_native_segwit) {
+		my $version = pack 'C', Bitcoin::Crypto::Constants::segwit_witness_version;
+		return $segwit->($version, $address);
+	}
+	elsif ($self->type eq 'P2TR') {
+		my $version = pack 'C', Bitcoin::Crypto::Constants::taproot_witness_version;
+		return $segwit->($version, $address);
 	}
 	elsif ($self->type eq 'P2PKH') {
 		return encode_base58check($self->network->p2pkh_byte . $address);
@@ -668,7 +680,7 @@ sub is_empty
 __END__
 =head1 NAME
 
-Bitcoin::Crypto::Script - Bitcoin script instance
+Bitcoin::Crypto::Script - Bitcoin Script instance
 
 =head1 SYNOPSIS
 
