@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Script::Recognition;
-$Bitcoin::Crypto::Script::Recognition::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Script::Recognition::VERSION = '2.00001';
+$Bitcoin::Crypto::Script::Recognition::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -87,6 +86,13 @@ sub _build_blueprints
 			]
 		],
 
+		[
+			P2TR => [
+				'OP_1',
+				['address', 32],
+			]
+		],
+
 		[
 			NULLDATA => [
 				'OP_RETURN',
