@@ -1,12 +1,11 @@
 package Bitcoin::Crypto::Segwit;
-$Bitcoin::Crypto::Segwit::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Segwit::VERSION = '2.00001';
+$Bitcoin::Crypto::Segwit::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
 use Exporter qw(import);
+use Carp qw(carp);
 
-use Bitcoin::Crypto::Helpers qw(carp_once);
 use Bitcoin::Crypto::Util;
 
 our @EXPORT_OK = qw(
@@ -20,7 +19,7 @@ our %validators = (
 
 sub validate_program
 {
-	carp_once
+	carp
 		"Bitcoin::Crypto::Segwit::validate_program is deprecated. Use Bitcoin::Crypto::Util::validate_segwit instead.";
 	goto \&Bitcoin::Crypto::Util::validate_segwit;
 }
@@ -30,7 +29,7 @@ sub validate_program
 __END__
 =head1 NAME
 
-Bitcoin::Crypto::Segwit - Segregated Witness version validators (DEPRECATED)
+Bitcoin::Crypto::Segwit - DEPRECATED
 
 =head1 SYNOPSIS
 
