@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Transaction::Input;
-$Bitcoin::Crypto::Transaction::Input::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Transaction::Input::VERSION = '2.00001';
+$Bitcoin::Crypto::Transaction::Input::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -9,7 +8,7 @@ use Moo;
 use Mooish::AttributeBuilder -standard;
 use Type::Params -sigs;
 
-use Bitcoin::Crypto qw(btc_utxo btc_script);
+use Bitcoin::Crypto qw(btc_script);
 use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Helpers qw(pack_varint unpack_varint);
 use Bitcoin::Crypto::Util qw(to_format);
@@ -18,9 +17,16 @@ use Bitcoin::Crypto::Types
 use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Script::Common;
 
+use namespace::clean;
+
 has param 'utxo' => (
 	coerce => (InstanceOf ['Bitcoin::Crypto::Transaction::UTXO'])
-		->plus_coercions(ArrayRef, q{ Bitcoin::Crypto::Transaction::UTXO->get(@$_) })
+		->plus_coercions(
+			ArrayRef, q{
+				require Bitcoin::Crypto::Transaction::UTXO;
+				Bitcoin::Crypto::Transaction::UTXO->get(@$_)
+			}
+		)
 );
 
 has param 'signature_script' => (
@@ -411,7 +417,7 @@ L<Bitcoin::Crypto::Exception> namespace:
 
 =over
 
-=item * Bitcoin::Crypto::Exception::Transaction - general error with transaction
+=item * Transaction - general error with transaction
 
 =back
 
