@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Transaction::Output;
-$Bitcoin::Crypto::Transaction::Output::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Transaction::Output::VERSION = '2.00001';
+$Bitcoin::Crypto::Transaction::Output::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -14,6 +13,8 @@ use Bitcoin::Crypto::Helpers qw(pack_varint unpack_varint ensure_length);    # l
 use Bitcoin::Crypto::Util qw(to_format);
 use Bitcoin::Crypto::Exception;
 
+use namespace::clean;
+
 has param 'value' => (
 	writer => 1,
 	coerce => (InstanceOf ['Math::BigInt'])
@@ -277,7 +278,7 @@ L<Bitcoin::Crypto::Exception> namespace:
 
 =over
 
-=item * Bitcoin::Crypto::Exception::Transaction - general error with transaction
+=item * Transaction - general error with transaction
 
 =back
 
