@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Transaction::UTXO;
-$Bitcoin::Crypto::Transaction::UTXO::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Transaction::UTXO::VERSION = '2.00001';
+$Bitcoin::Crypto::Transaction::UTXO::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -15,6 +14,8 @@ use Bitcoin::Crypto::Types qw(IntMaxBits Int PositiveOrZeroInt ByteStr InstanceO
 use Bitcoin::Crypto::Util qw(to_format);
 use Bitcoin::Crypto::Exception;
 
+use namespace::clean;
+
 my %utxos;
 my $loader;
 
@@ -96,7 +97,7 @@ sub get
 
 signature_for set_loader => (
 	method => Str,
-	positional => [Maybe[CodeRef]],
+	positional => [Maybe [CodeRef]],
 );
 
 sub set_loader
@@ -270,7 +271,7 @@ L<Bitcoin::Crypto::Exception> namespace:
 
 =over
 
-=item * Bitcoin::Crypto::Exception::UTXO - UTXO was not found
+=item * UTXO - UTXO was not found
 
 =back
 
