@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Types;
-$Bitcoin::Crypto::Types::VERSION = '2.000_01'; # TRIAL
-$Bitcoin::Crypto::Types::VERSION = '2.00001';
+$Bitcoin::Crypto::Types::VERSION = '2.001';
 use v5.10;
 use strict;
 use warnings;
@@ -69,7 +68,7 @@ $bytestr->coercion->add_type_coercions(
 
 my $scripttype = __PACKAGE__->add_type(
 	name => 'ScriptType',
-	parent => Enum->of(qw(P2PK P2PKH P2SH P2MS P2WPKH P2WSH NULLDATA))
+	parent => Enum->of(qw(P2PK P2PKH P2SH P2MS P2WPKH P2WSH P2TR NULLDATA))
 );
 
 my $scriptdesc = __PACKAGE__->add_type(
